.. _joining_dataframes_ref:
.. currentmodule:: skrub

Joining dataframes
==================

.. autosummary::
   :toctree: generated/
   :template: class.rst
   :nosignatures:

   Joiner
   AggJoiner
   MultiAggJoiner
   AggTarget
   InterpolationJoiner

.. autosummary::
   :toctree: generated/
   :template: function.rst
   :nosignatures:

   fuzzy_join
